@@ -306,7 +306,7 @@ between buffer substrings \":PROPERTIES:\" and \":END:\"."
     ;; care of it, but el-job was never called).  Set them now.
     (dolist (var (org-mem--mk-work-vars))
       (set (car var) (cdr var)))
-    (dolist (var org-mem-inject-vars)
+    (dolist (var (el-job-ng-vars org-mem-inject-vars))
       (cl-assert (consp var))
       (unless (equal (symbol-value (car var)) (cdr var))
         (when (y-or-n-p (format "Globally set %S?  To: %s"
@@ -357,7 +357,7 @@ between buffer substrings \":PROPERTIES:\" and \":END:\"."
             (setq bad-path file)
             (signal 'skip-file t))
           (when (not (file-readable-p file))
-            ;; NOTE: Don't declare it bad, that'd delist it from
+            ;; NOTE: Don't declare it a bad-path, that'd delist it from
             ;;       org-id-locations, which the user may not want.
             (error "Code 8: File not readable"))
           ;; NOTE: Don't use `insert-file-contents-literally'!  It sets
@@ -635,7 +635,7 @@ between buffer substrings \":PROPERTIES:\" and \":END:\"."
                         (list clock-start))
                       CLOCK-LINES)))
 
-            ;; `CRUMBS' is a kind of state machine; a list that can look like
+            ;; `CRUMBS' is kind of a state machine; a list that can look like
             ;;    ((3 23 500 "Heading" "id1234" ("noexport" "work" "urgent"))
             ;;     (2 10 122 "Another heading" "id6532" ("work"))
             ;;     (... ... ... ...))
@@ -697,7 +697,7 @@ between buffer substrings \":PROPERTIES:\" and \":END:\"."
           ;; Done analyzing this file.
           (cl-assert (eobp))
           (setq file-data (list file
-                                (file-attributes file 'string)
+                                (file-attributes file)
                                 LNUM
                                 (point)
                                 coding-system)))
@@ -708,23 +708,23 @@ between buffer substrings \":PROPERTIES:\" and \":END:\"."
        (setq problem (list (format-time-string "%H:%M") file (point) err))
        (widen)
        (setq file-data (list file
-                             (file-attributes file 'string)
+                             (file-attributes file)
                              (line-number-at-pos (point-max))
                              (point-max)
                              coding-system)))
 
-      ;; Catch fake `skip-file' signal.
+      ;; Catch fake `skip-file' signal.  Already caught real error signals.
       (t
+       (cl-assert (null problem))
        (cl-assert (null file-data))
        (cl-assert (null found-entries))
-       (cl-assert (null org-mem-parser--found-links))
-       (cl-assert (null problem))))
+       (cl-assert (null org-mem-parser--found-links))))
 
-    (list (if bad-path (list bad-path))
-          (if file-data (list file-data))
+    (list bad-path
+          problem
+          file-data
           found-entries
-          org-mem-parser--found-links
-          (if problem (list problem)))))
+          org-mem-parser--found-links)))
 
 (provide 'org-mem-parser)
 
