@@ -19,8 +19,8 @@
 ;; URL:      https://github.com/meedstrom/org-mem
 ;; Created:  2025-03-15
 ;; Keywords: text
-;; Package-Version: 0.27.1
-;; Package-Revision: 0.27.1-0-g6d1d2129f595
+;; Package-Version: 0.27.2
+;; Package-Revision: 0.27.2-0-g6fa947a5872d
 ;; Package-Requires: ((emacs "29.1") (el-job "2.7.1") (llama "0.5.0"))
 
 ;;; Commentary:
@@ -1753,12 +1753,12 @@ Old style was a list of 5 lists:
 
    \(BAD-PATHS FILE-DATA ENTRIES LINKS PROBLEMS)"
   (cl-loop
-   for (badpath problem fdatum entries links) in (copy-sequence ng-style-results)
+   for (badpath problem fdatum entries links) in ng-style-results
    when badpath collect badpath into badpaths
    when problem collect problem into problems
    when fdatum collect fdatum into fdata
-   nconc entries into all-entries
-   nconc links into all-links
+   append entries into all-entries
+   append links into all-links
    finally return (list badpaths fdata all-entries all-links problems)))
 
 
@@ -1810,7 +1810,7 @@ org-id-locations:
 
 
 (defvaralias 'org-mem-internal-version 'org-mem--bump-int) ; Alias added 2026-01-27 (after 0.26.3)
-(defconst org-mem--bump-int 23 "Not a version number, but bumped sometimes.")
+(defconst org-mem--bump-int 24 "Not a version number, but bumped sometimes.")
 
 (defmacro org-mem--def-whiny-alias (old new when removed-by)
   "Define function OLD as effectively an alias for NEW.
